aboutsummaryrefslogtreecommitdiffstats
path: root/oni-php.el
diff options
context:
space:
mode:
Diffstat (limited to 'oni-php.el')
-rw-r--r--oni-php.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/oni-php.el b/oni-php.el
index a61bb6f..4b21c9c 100644
--- a/oni-php.el
+++ b/oni-php.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 20190306003024
;; Package-Requires: (php-mode oni-flycheck oni-company oni-fci ggtags fic-mode hydra company-php)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ nil for some reason."
(add-hook 'php-mode-hook 'fic-mode)
(add-hook 'php-mode-hook 'flycheck-mode)
(add-hook 'php-mode-hook 'ggtags-mode)
+(add-hook 'php-mode-hook 'phpcbf-enable-on-save)
(with-eval-after-load 'company
(add-to-list 'company-backends 'company-ac-php-backend))
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 20190306003024
-;; Package-Requires: (php-mode oni-flycheck oni-company oni-fci ggtags fic-mode hydra company-php)
+;; Version: 20190505200117
+;; Package-Requires: (php-mode oni-flycheck oni-company oni-fci ggtags fic-mode hydra company-php phpcbf)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by